@@ -21,7 +21,7 @@ from mintpy.objects.coord import coordinate
 from mintpy.utils import ptime, readfile, time_func, utils1 as ut
 
 GNSS_SITE_LIST_URLS = {
-    'UNR'      : 'http://geodesy.unr.edu/NGLStationPages/DataHoldings.txt',
+    'UNR'      : 'https://geodesy.unr.edu/NGLStationPages/DataHoldings.txt',
     'ESESES'   : 'http://garner.ucsd.edu/pub/measuresESESES_products/Velocities/ESESES_Velocities.txt',
     'SIDESHOW' : 'https://sideshow.jpl.nasa.gov/post/tables/table2.html',
     'GENERIC'  : None,
@@ -71,7 +71,8 @@ def search_gnss(SNWE, start_date=None, end_date=None, source='UNR', site_list_fi
 
     # ensure that site data formatting is consistent
     sites['site'] = np.array([site.upper() for site in sites['site']])
-    sites['lon'][sites['lon'] > 180] -= 360         # ensure lon values in (-180, 180]
+    # ensure longitude values in (-180, 180]
+    sites['lon'] = ut.standardize_longitude(sites['lon'], limit='-180to180')
     vprint(f'load {len(sites["site"]):d} GNSS sites with fields: {" ".join(sites.keys())}')
 
     # limit in space
@@ -818,7 +819,7 @@ class GNSS_UNR(GNSS):
         # examples: http://geodesy.unr.edu/gps_timeseries/tenv3/IGS08/1LSU.IGS08.tenv3
         #           http://geodesy.unr.edu/gps_timeseries/tenv3/IGS14/CASU.tenv3
         if not self.url_prefix:
-            self.url_prefix = f'http://geodesy.unr.edu/gps_timeseries/tenv3/{self.version}'
+            self.url_prefix = f'https://geodesy.unr.edu/gps_timeseries/tenv3/{self.version}'
         self.url = os.path.join(self.url_prefix, os.path.basename(self.file))
 
 
@@ -844,8 +845,8 @@ class GNSS_UNR(GNSS):
 
         # get plot file url
         url_prefix = {
-            'IGS08' : 'http://geodesy.unr.edu/tsplots/IGS08/TimeSeries',
-            'IGS14' : 'http://geodesy.unr.edu/tsplots/IGS14/IGS14/TimeSeries',
+            'IGS08' : 'https://geodesy.unr.edu/tsplots/IGS08/TimeSeries',
+            'IGS14' : 'https://geodesy.unr.edu/tsplots/IGS14/IGS14/TimeSeries',
         }[self.version]
         plot_file_url = os.path.join(url_prefix, f'{self.site}.png')
 
@@ -867,6 +868,9 @@ class GNSS_UNR(GNSS):
 
         data = np.loadtxt(self.file, dtype=bytes, skiprows=1, max_rows=10)
         self.site_lat, self.site_lon = data[0, 20:22].astype(float)
+        # ensure longitude in the range of (-180, 180]
+        self.site_lon = ut.standardize_longitude(self.site_lon, limit='-180to180')
+
         return self.site_lat, self.site_lon
 
 
@@ -987,8 +991,9 @@ class GNSS_ESESES(GNSS):
             # longitude
             lon_line = [x for x in lines if x.startswith('# East Longitude')][0].strip('\n')
             self.site_lon = float(lon_line.split()[-1])
-            # ensure longitude in the range of (-180, 180]
-            self.site_lon -= 0 if self.site_lon <= 180 else 360
+
+        # ensure longitude in the range of (-180, 180]
+        self.site_lon = ut.standardize_longitude(self.site_lon, limit='-180to180')
 
         return self.site_lat, self.site_lon
 
@@ -1082,6 +1087,8 @@ class GNSS_SIDESHOW(GNSS):
         """
         # need to refer to the site list
         site_list_file = os.path.basename(GNSS_SITE_LIST_URLS['SIDESHOW'])
+        if not os.path.exists(site_list_file):
+            dload_site_list(out_file=site_list_file, source=self.source, print_msg=True)
 
         # find site in site list file
         with open(site_list_file) as site_list:
@@ -1092,6 +1099,8 @@ class GNSS_SIDESHOW(GNSS):
         # format
         self.site_lat = float(site_lat)
         self.site_lon = float(site_lon)
+        # ensure longitude in the range of (-180, 180]
+        self.site_lon = ut.standardize_longitude(self.site_lon, limit='-180to180')
 
         if print_msg == True:
             print(f'\t{self.site_lat:f}, {self.site_lon:f}')
@@ -1183,7 +1192,11 @@ class GNSS_GENERIC(GNSS):
         """
         sites = read_GENERIC_site_list('GenericList.txt')
         ind = sites['site'].tolist().index(self.site)
-        return sites['lat'][ind], sites['lon'][ind]
+        site_lat, site_lon = sites['lat'][ind], sites['lon'][ind]
+        # ensure longitude in the range of (-180, 180]
+        site_lon = ut.standardize_longitude(site_lon, limit='-180to180')
+
+        return site_lat, site_lon
 
 
     def read_displacement(self, start_date=None, end_date=None, print_msg=True, display=False):
