@@ -14,10 +14,12 @@ SENSOR_NAME_VARIATION = {
     'alos'  : ['alos', 'alos1', 'palsar', 'palsar1'],
     'alos2' : ['alos2', 'palsar2'],
     'alos4' : ['alos4', 'palsar3'],
+    'bio'   : ['bio', 'biomass'],
     'csk'   : ['csk', 'csk1', 'csk2', 'csk3', 'csk4', 'cos', 'cosmo', 'cosmoskymed'],
     'env'   : ['env', 'envisat', 'asar'],
     'ers'   : ['ers', 'ers1', 'ers2', 'ers12'],
     'gf3'   : ['gfen3', 'gaofen3', 'g3', 'gaofen'],
+    'hj1c'  : ['hj1', 'huanjing1c'],
     'jers'  : ['jers', 'jers1'],
     'ksat5' : ['ksat5', 'kompsat5', 'kompsat', 'kmps5'],
     'lt1'   : ['lt1', 'lt', 'lutan', 'lutan1'],
@@ -195,8 +197,28 @@ def get_unavco_mission_name(meta_dict):
 # JERS       : SNR = 14 dB from https://directory.eoportal.org/web/eoportal/satellite-missions/j/jers-1
 
 
+##--------------------  Ka-band  -------------------##
+# SWOT
+# launch date: 2022-12-16
+# end    date: operational
+# KaRIn (Ka-band Radar Interferometer) On-Board Processor (OBP) ATBD
+SWOT = {
+    # orbit
+    'altitude'                   : 906e3,     # m
+    'orbit_inclination'          : 78,        # deg
+    # sar / antenna
+    'carrier_frequency'          : 35.75e9,   # Hz
+    'pulse_repetition_frequency' : 4420,      # Hz
+    'chirp_bandwidth'            : 200e6,     # Hz
+    'sampling_frequency'         : 300e6,     # Hz
+}
+
+
+
 ##--------------------  X-band  --------------------##
 # TerraSAR-X stripmap mode in single polarization
+# launch date: 2007-06-15 (TSX), 2010-06-21 (TDX)
+# end    date: operational
 # from Table 1 in Jung et al. (2014)
 # https://www.eoportal.org/satellite-missions/terrasar-x
 TSX = {
@@ -217,6 +239,8 @@ TSX = {
 }
 
 # COSMO-SkyMed stripmap HIMAGE mode
+# launch date: 2007-06-08 (CSK1), 2007-12-09 (CSK2), 2008-10-25 (CSK3), 2010-11-06 (CSK4)
+# end    date: operational
 # from Table 1 in Jung et al. (2014)
 # https://www.eoportal.org/satellite-missions/cosmo-skymed
 CSK = {
@@ -237,6 +261,8 @@ CSK = {
 }
 
 # Kompsat-5 (Korea Multi-Purpose Satellite-5) stripmap mode
+# launch date: 2013-08-22
+# end    date: operational
 # from Table 1 in Jung et al. (2014)
 # https://www.eoportal.org/satellite-missions/kompsat-5
 KSAT5 = {
@@ -276,6 +302,8 @@ ICEYE = {
 ##--------------------  C-band  --------------------##
 
 # ERS-1/2
+# launch date: 1991-07-17 (ERS-1), 1995-04-21 (ERS-2)
+# end    date: 2000-03-10 (ERS-1), 2011-09-05 (ERS-2)
 # from Table 2 in Jung et al. (2014)
 # from Imaging Radar class by Howard Zebker, 2021.
 # https://www.esa.int/esapub/bulletin/bullet83/duc83.htm
@@ -300,6 +328,8 @@ ERS = {
 }
 
 # Envisat
+# lauch date: 2002-03-01
+# end   date: 2012-04-08
 # from Table 2 in Jung et al. (2014)
 # https://earth.esa.int/eogateway/missions/envisat/description
 # https://www.eoportal.org/satellite-missions/envisat#asar-advanced-sar
@@ -321,6 +351,8 @@ ENV = {
 }
 
 # Radarsat-1
+# launch date: 1995-11-04
+# end    date: 2013-03-29
 # https://www.asc-csa.gc.ca/eng/satellites/radarsat/technical-features/radarsat-comparison.asp
 RSAT1 = {
     # orbit
@@ -334,6 +366,8 @@ RSAT1 = {
 }
 
 # Radarsat-2 stripmap ultra-fine mode
+# launch date: 2007-12-14
+# end    date: operational
 # from Table 2 in Jung et al. (2014)
 RSAT2 = {
     # orbit
@@ -352,7 +386,10 @@ RSAT2 = {
 }
 
 # Radarsat Constellation Mission
+# launch date: 2019-06-12
+# end    date: operational
 # https://www.asc-csa.gc.ca/eng/satellites/radarsat/technical-features/radarsat-comparison.asp
+# Cote et al. (2021) at https://ieeexplore.ieee.org/document/9472534
 RCM = {
     # orbit
     'altitude'                   : 600.5e3,   # m, mean value, 586-615 km
@@ -362,12 +399,17 @@ RCM = {
     'carrier_frequency'          : 5.405e9,   # Hz
     'antenna_length'             : 6.75,      # m
     'antenna_width'              : 1.38,      # m
+    'chirp_bandwidth'            : 100e6,     # Hz
+    'noise_equivalent_sigma_zero': -19,       # dB, [-17, -25] for all modes
 }
 
 # GaoFen-3
+# launch date: 2016-08-10 (GF3-01), 2021-11-23 (GF3-02), 2022-04-07 (GF3-03)
+# end    date: operational
 # Table 2 & 6 in https://directory.eoportal.org/web/eoportal/satellite-missions/g/gaofen-3
 # https://www.eoportal.org/satellite-missions/gaofen-3
 # Li et al. (2018, RS) at https://doi.org/10.3390/rs10121929
+# Table I in Yang et al. (2023, IEEE-TGRS) at https://doi.org/10.1109/TGRS.2023.3238707
 GF3 = {
     # orbit
     'altitude'                   : 755e3,     # m
@@ -376,26 +418,35 @@ GF3 = {
     # sar / antenna
     'carrier_frequency'          : 5.4e9,     # Hz
     'antenna_length'             : 15,        # m
-    'antenna_width'              : 1.5,       # m
-    'sampling_frequency'         : 533.33e6,  # Hz
+    'antenna_width'              : 1.232,     # m
+    'pulse_repetition_frequency' : 1412.18,   # Hz
+    'chirp_bandwidth'            : 60.00e6,   # Hz
+    'sampling_frequency'         : 533.33e6,  # Hz, IF sampling
+    'azimuth_pixel_size'         : 4.77,      # m, FSII mode
+    'range_pixel_size'           : 2.25,      # m, FSII mode
+    'noise_equivalent_sigma_zero': -19.5,     # dB, -19.5/-21.3 dB for P,UF,F,WF,Q,WV/S,NS,WS,G,WQ,E modes
 }
 
 # Sentinel-1 Interferometric Wide (IW / TOPS) swath mode
+# launch date: 2014-04-03  (S1A), 2016-04-25 (S1B), 2024-12-05  (S1C)
+# end    date: operational (S1A), 2021-12-23 (S1B), operational (S1C)
 # Typical value:
 # azfact = azResolution / azPixelSize = 1.46
 # rgfact = rgResolution / rgPixelSize = 1.33
 # reference:
 #   1. Table 2 & Fig. 5d in Jung et al. (2014)
 #   2. Table 3-1 & 7-5 in https://sentinel.esa.int/documents/247904/1877131/Sentinel-1-Product-Definition
+#   3. Fig. 4 in Miranda et al. (2016) at https://doi.org/10.1016/j.procs.2016.09.247
+#   4. https://www.eoportal.org/satellite-missions/copernicus-sentinel-1
 SEN = {
     # orbit
     'altitude'                   : 705e3,     # m, mean value
     'orbit_inclination'          : 98.18,     # deg
     'repeat_cycle'               : 12,        # day, single satellite
     # sar / antenna
-    'carrier_frequency'          : 5.405e9,   # Hz
+    'carrier_frequency'          : 5.405e9,   # Hz, 5.55 cm wavelength
     'antenna_length'             : 12.3,      # m
-    'antenna_width'              : 0.82,      # m
+    'antenna_width'              : 0.821,      # m
     'doppler_bandwidth'          : 380,       # Hz
     'pulse_repetition_frequency' : 1717.13,   # Hz, based on real data; 1000-3000 (programmable)
     'chirp_bandwidth'            : 56.50e6,   # Hz
@@ -406,12 +457,54 @@ SEN = {
     'IW1' : {'range_resolution' : 2.7, 'azimuth_resolution': 22.5},
     'IW2' : {'range_resolution' : 3.1, 'azimuth_resolution': 22.7},
     'IW3' : {'range_resolution' : 3.5, 'azimuth_resolution': 22.6},
+    'noise_equivalent_sigma_zero': -22,       # dB
+}
+
+
+##--------------------  S-band  --------------------##
+
+# HJ-1C (Huan Jing-1C)
+# launch date: 2012-11-19
+# end    date: operational
+# https://www.eoportal.org/satellite-missions/hj-1
+# Liu et al. (2014, J Radar), doi: 10.3724/SP.J.1300.2013.13050
+# Zhang et al. (2014, J Radar), doi: https://doi.org/10.3724/SP.J.1300.2014.13135
+# spatial resolution: 10 m (4 looks)
+# swath width: 100 km
+HJ1C = {
+    # orbit
+    'altitude'                   : 502e3,     # m
+    'orbit_inclination'          : 97.3,      # deg
+    'repeat_cycle'               : 31,        # day
+    # sar / antenna
+    'carrier_frequency'          : 3.13e9,    # Hz
+    'pulse_repetition_frequency' : 2600,      # Hz, 2600-3700
+    'chirp_bandwidth'            : 60.0e6,    # Hz
+    'noise_equivalent_sigma_zero': -22,       # dB
+}
+
+# NISAR S-band
+# https://nisar.jpl.nasa.gov/system/documents/files/26_NISAR_FINAL_9-6-19.pdf
+NISAR_S = {
+    # orbit
+    'altitude'                   : 747e3,     # m
+    'orbit_inclination'          : 98.4,      # degree
+    'repeat_cycle'               : 12,        # day
+    # sar / antenna
+    'carrier_frequency'          : 3.2e9,     # Hz
+    'antenna_radius'             : 12,        # m
+    'pulse_repetition_frequency' : 2200,      # Hz
+    'chirp_bandwidth'            : 75e6,      # Hz
+    'azimuth_resolution'         : 7,         # m
+    'noise_equivalent_sigma_zero': -20,       # dB (threshold), -25 dB (baseline)
 }
 
 
 ##--------------------  L-band  --------------------##
 
 # Seasat
+# launch date: 1978-06-27
+# end    date: 1978-10-10
 # from Table 6-1 in Kim and Jordan (2006)
 # https://www.eoportal.org/satellite-missions/seasat
 SEASAT = {
@@ -428,8 +521,12 @@ SEASAT = {
 }
 
 # JERS-1
+# launch date: 1992-02-11
+# end    date: 1998-10-12
 # from Table 3 in Jung et al. (2014)
 # https://www.eoportal.org/satellite-missions/jers-1
+# https://www.eorc.jaxa.jp/ALOS/en/jers-1/sensor/sar_e.htm
+# swath_width: 75 km
 JERS = {
     # orbit
     'altitude'                   : 568e3,     # m, mean value
@@ -448,8 +545,11 @@ JERS = {
 }
 
 # ALOS PALSAR FBS (fine beam single polarization) mode
+# launch date: 2006-01-24
+# end    date: 2011-04-22
 # from Table 3 in Jung et al. (2014)
 # https://www.eorc.jaxa.jp/ALOS/en/alos/a1_about_e.htm
+# https://www.eorc.jaxa.jp/ALOS/en/alos/sensor/palsar_e.htm
 ALOS = {
     # orbit
     'altitude'                   : 691.65e3,  # m, mean value
@@ -458,19 +558,23 @@ ALOS = {
     # sar / antenna
     'carrier_frequency'          : 1.270e9,   # Hz
     'antenna_length'             : 8.9,       # m
+    'antenna_width'              : 3.1,       # m
     'doppler_bandwidth'          : 1700,      # Hz
     'pulse_repetition_frequency' : 2160,      # Hz
-    'chirp_bandwidth'            : 28.00e6,   # Hz
+    'chirp_bandwidth'            : 28.00e6,   # Hz, 14/28
     'sampling_frequency'         : 32.00e6,   # Hz
     'azimuth_pixel_size'         : 3.5,       # m
     'ground_range_pixel_size'    : 7.4,       # m
     'range_pixel_size' : {
         'stripmap_FBD' : 9.37,                # m
         'stripmap_FBS' : 4.68,                # m
-    }
+    },
+    'noise_equivalent_sigma_zero': -23,       # dB, -23/-25 dB for swath width 70/60km
 }
 
 # ALOS-2 PALSAR-2 stripmap ultra-fine single polarization mode
+# launch date: 2014-05-24
+# end    date: operational
 # from Table 3 in Jung et al. (2014) and eoPortal Table 10-11.
 # eoPortal: https://www.eoportal.org/satellite-missions/alos-2
 #   Parameter       Spotlight               Stripmap            ScanSAR
@@ -500,19 +604,31 @@ ALOS2 = {
         'stripmap_ultrafine'     : 1.43,      # m
         'stripmap_highsensitive' : 2.86,      # m
         'scansar_normal'         : 8.58,      # m
-    }
+    },
+    'noise_equivalent_sigma_zero': -24,       # dB, -24/-26/-28
 }
 
 # ALOS-4 PALSAR-3
+# launch date: 2024-07-01
+# end    date: operational
 # https://www.eorc.jaxa.jp/ALOS/en/alos-4/a4_about_e.htm
+# https://www.eorc.jaxa.jp/ALOS/en/alos-4/a4_sensor_e.htm
+# using stripmap 200km@3m mode as reference
 ALOS4 = {
     # orbit (same as ALOS-2)
     'altitude'                   : 628e3,     # m, mean value
     'orbit_inclination'          : 97.9,      # deg
     'repeat_cycle'               : 14,        # day, (15-3/14 rev/day)
+    # sar / antenna
+    'carrier_frequency'          : 1257.5e6,  # Hz (spotlight, 3m SM), 1236.5/1257.5/1278.5 MHz
+    'chirp_bandwidth'            : 84e6,      # Hz, 84/42/28
+    'range_resolution'           : 3,         # m
+    'noise_equivalent_sigma_zero': -20,       # dB, -20/-24/-28
 }
 
 # SAOCOM-1A/B stripmap
+# launch date: 2018-10-08 (SAOCOM-1A), 2020-08-30 (SAOCOM-1B)
+# end    date: operational
 # from Giudici et al. (2017) and
 # https://directory.eoportal.org/web/eoportal/satellite-missions/s/saocom
 # https://www.eoportal.org/satellite-missions/saocom
@@ -526,9 +642,13 @@ SAOCOM = {
     'antenna_length'             : 10,        # m
     'pulse_repetition_frequency' : 4545,      # Hz
     'sampling_frequency'         : 50.0e6,    # Hz
+    'noise_equivalent_sigma_zero': -28,       # dB (single/dual pol modes), -34 dB for quad pol modes
 }
 
 # LuTan-1 (stripmap mode)
+# launch date: 2022-01-26 (LT1A), 2022-02-27 (LT1B)
+# end    date: operational
+# Table 1 from Wang et al. (2024, GRSM) at https://doi.org/10.1109/MGRS.2024.3478761
 # Table 1 from Liu et al. (2022, EUSAR) at https://ieeexplore.ieee.org/document/9944327
 # preliminary version: the azimuth bandwidth/frequency/pixelsize might change
 LT1 = {
@@ -542,11 +662,41 @@ LT1 = {
     'antenna_width'              : 3.4,       # m
     'doppler_bandwidth'          : 2544,      # Hz
     'pulse_repetition_frequency' : 2934,      # Hz
-    'chirp_bandwidth'            : 60.0e6,    # Hz
+    'chirp_bandwidth'            : 80.0e6,    # Hz
     'azimuth_pixel_size'         : 2.35,      # m
-    'range_pixel_size'           : 1.67,      # m
     'azimuth_resolution'         : 7.15,      # m
+    'range_pixel_size'           : 1.67,      # m
     'range_resolution'           : 2.50,      # m
+    'noise_equivalent_sigma_zero': -28,       # dB
+}
+
+# UAVSAR-L
+# Reference:
+#   https://earth.jpl.nasa.gov/estd-missions/airborne/uavsar/
+#   https://airbornescience.nasa.gov/instrument/Uninhabited_Aerial_Vehicle_Synthetic_Aperture_Radar
+#   https://www.eoportal.org/other-space-activities/uavsar
+#   Fore et al. (2015) at https://doi.org/10.1109/TGRS.2014.2377637
+#   Hu et al. (2020) at https://doi.org/10.1038/s41467-020-16617-7
+# Parameters:
+#   swath width = 16e3 m
+#   fly path accuracy <= 10 m
+#   instrument power = 3.1e3 W
+#   noise equivalent sigma zero < -50 dB
+#   operating altitude range = 2e3 - 18e3 m
+#   ground speed range = 100 - 250 m/s
+UAV_L = {
+    # orbit
+    'altitude'                   : 13.8e3,    # m, 2 - 18 km
+    # sar / antenna
+    'carrier_frequency'          : 1.2575e9,  # Hz, 23.70 cm wavelength
+    'antenna_length'             : 1.6,       # m
+    'antenna_width'              : 0.5,       # m
+    'chirp_bandwidth'            : 80e6,      # Hz
+    'range_resolution'           : 1.8,       # m
+    'range_pixel_size'           : 1.67,      # m
+    'azimuth_resolution'         : 0.8,       # m
+    'azimuth_pixel_size'         : 0.6,       # m
+    'noise_equivalent_sigma_zero': -50,       # dB
 }
 
 # NISAR
@@ -565,10 +715,36 @@ NISAR_L = {
         '24MHz'                  : 6.25,      # m
         '44MHz'                  : 3.41,      # m
         '80MHz'                  : 1.87,      # m
-    }
+    },
+    'noise_equivalent_sigma_zero': -25,       # dB
 }
 
 
+##--------------------  P-band  --------------------##
+
+# Biomass
+# launch date: 2025-04-29
+# end    date: operational
+# https://www.eoportal.org/satellite-missions/biomass
+# Zhu et al. (2024) at https://doi.org/10.13203/j.whugis20240220
+# swath width ~= 50e3  # m
+BIOMASS = {
+    # orbit
+    'altitude'                   : 666e3,     # m, mean value
+    'orbit_inclination'          : 98,        # deg
+    'repeat_cycle'               : 3,         # day
+    # sar / antenna
+    'carrier_frequency'          : 435e6,     # Hz, 70 cm wavelength
+    'antenna_length'             : 12,        # m
+    'pulse_repetition_frequency' : 2000,      # Hz, 2000~4000
+    'chirp_bandwidth'            : 6e6,       # Hz
+    'range_pixel_size'           : 25,        # m
+    'azimuth_pixel_size'         : 8,         # m
+    'noise_equivalent_sigma_zero': -27,       # dB (threshold), -30 dB (goal)
+}
+
+
+
 SENSOR_DICT = {
     # X-band
     'tsx'   : TSX,
@@ -583,11 +759,16 @@ SENSOR_DICT = {
     'rsat2' : RSAT2,
     'rcm'   : RCM,
     'gf3'   : GF3,
+    # S-band
+    'hj1c'  : HJ1C,
     # L-band
     'jers'  : JERS,
     'alos'  : ALOS,
     'alos2' : ALOS2,
     'alos4' : ALOS4,
     'lt1'   : LT1,
+    'uav'   : UAV_L,
     'ni'    : NISAR_L,
+    # P-band
+    'bio'   : BIOMASS,
 }
